<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>LXQtCustomCommand</name>
    <message>
        <location filename="../lxqtcustomcommand.cpp" line="186"/>
        <source>Error</source>
        <translation>Greška</translation>
    </message>
</context>
<context>
    <name>LXQtCustomCommandConfiguration</name>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="14"/>
        <source>Custom Command Configuration</source>
        <translation>Prilagođena naredba – konfiguracija</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="20"/>
        <source>Display</source>
        <translation>Prikaz</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="181"/>
        <source>Use icon from theme or browse file</source>
        <translation>Koristi ikonu teme ili odaberi datoteku</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="188"/>
        <source>Run with &quot;bash -c&quot;</source>
        <translation>Pokreni s &quot;bash -c&quot;</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="198"/>
        <source>Select Font</source>
        <translation>Odaberi font</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="218"/>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="135"/>
        <source>Command</source>
        <translation>Naredba</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="128"/>
        <source>Font</source>
        <translation>Font</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="162"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="208"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="211"/>
        <source>Use %1 to display command output</source>
        <translation>Koristi %1 za prikaz rezultata naredbe</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="145"/>
        <source>Icon</source>
        <translation>Ikona</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="108"/>
        <source>Browse</source>
        <translation>Odaberi</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="155"/>
        <source>Autorotate when the panel is vertical</source>
        <translation>Automatski okreni kad ploča stoji okomito</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="240"/>
        <source>echo Configure...</source>
        <translation>echo konfiguriraj …</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="243"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="278"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="285"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="292"/>
        <source>Command to run</source>
        <translation>Naredba koja će se pokrenuti</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="118"/>
        <source>Max Width</source>
        <translation>Maks. širina</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="70"/>
        <source>Repeat command after:</source>
        <translation>Ponovi naredbu nakon:</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="86"/>
        <source> second(s)</source>
        <translation> s</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="250"/>
        <source>Command outputs an image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="262"/>
        <source>Mouse Commands</source>
        <translation>Naredbe za mišje funkcije</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="268"/>
        <source>Click</source>
        <translation>Pritiskanje tipke</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="299"/>
        <source>Wheel Up</source>
        <translation>Okretanje kotačića prema gore</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="309"/>
        <source>Wheel Down</source>
        <translation>Okretanje kotačića prema dolje</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="147"/>
        <source>Select Icon File</source>
        <translation>Odaberi datoteku ikone</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="147"/>
        <source>Images (*.png *.svg *.xpm *.jpg)</source>
        <translation>Slike (*.png *.svg *.xpm *.jpg)</translation>
    </message>
</context>
</TS>
